Python rules
============

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   python/001_positional_args_not_allowed.md
   python/002_return_type_hints.md
   python/003_nested_datetime_import.md
   python/004_dataclass_kw_only.md
   python/005_service_class_with_process.md
   python/006_abstract_class_inherits_from_abc.md
   python/007_variable_names_no_type_hinting.md
   python/008_no_loops_in_unittests.md
